==========================================
Cached Instances for Django REST Framework
==========================================

.. include:: ../README.rst
    :start-after: .. Omit badges from docs

Contents:

.. toctree::
   :maxdepth: 2

   project
   installation
   usage
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
